SideLocus

Struct SideLocus 

pub struct SideLocus {
    pub side_byte_off: u64,
    pub side_num: u64,
    pub char_off: u32,
    pub by: i32,
    pub bp: i32,
}
Position within the FM-index

This corresponds to the SideLocus struct in the C++ code. The FM-index is organized into “sides” of fixed size for efficient cache access.

Fields

side_byte_off: u64

Offset of side within ebwt[] (in bytes)

side_num: u64

Index of side

char_off: u32

Character offset within side (0 to sideBwtLen-1)

by: i32

Byte within side (0 to sideBwtSz-1)

bp: i32

Bit-pair within byte (0-3)

Implementations

Source

impl SideLocus

pub fn new() -> Self

Create a new invalid SideLocus (default state)

pub fn init_from_row(&mut self, row: u64, ep: &EbwtParams, ebwt: &[u8])

Initialize from a BWT row position

Arguments
  • row - BWT row position
  • ep - Ebwt parameters
  • ebwt - Pointer to ebwt data (for prefetching)
Safety

The ebwt pointer must be valid for the lifetime of this SideLocus.

pub fn init_from_top_bot( top: u64, bot: u64, ep: &EbwtParams, ebwt: &[u8], ) -> (Self, Self)

Initialize two SideLocus objects from a top/bot pair

This is an optimized version that uses the result from one call to initFromRow to possibly avoid a second call.

pub fn prefetch_from_row(row: u64, ep: &EbwtParams, ebwt: &[u8])

Prefetch cache lines for a given row

pub fn prefetch(&self, ebwt: &[u8])

Prefetch cache lines for this SideLocus

pub fn next_side(&mut self, ep: &EbwtParams)

Transform this SideLocus to refer to the next side

pub fn valid(&self) -> bool

Check if this is a valid (initialized) SideLocus

pub fn is_valid(&self, _ep: &EbwtParams) -> bool

Check if this SideLocus is valid with respect to given parameters

pub fn to_bw_row(&self) -> u64

Convert locus to BW row it corresponds to

pub fn invalidate(&mut self)

Invalidate this SideLocus (make it look like an invalid one)

pub fn side<'a>(&self, ebwt: &'a [u8]) -> &'a [u8]

Get a read-only pointer to the beginning of the top side

pub fn byte_offset(&self) -> u64

Get the actual byte offset in the mmapped data

pub fn mask(&self) -> u8

Get the mask for extracting the bit-pair at this position

pub fn extract(&self, data: &[u8]) -> u8

Extract the nucleotide pair at this locus from data